@@ -53,7 +53,7 @@ This class contains the helper methods used to register, deploy, and test the cr
 """
 import enum
 import sys
-import re
+# import re
 import pandas
 import requests
 import inspect
@@ -244,7 +244,7 @@ class QueueTask(Task):
         api_inputs : ApiInputs
             object returned by call to initialize()
         messages:List)
-            list of serialzed json strings which have been consumeed from the queue
+            list of serialized json strings which have been consumed from the queue
 
         """
         pass
@@ -424,7 +424,6 @@ class Automation:
                 "Driver must be an implementation of the Abstract Base Class (Task).")
             return False
 
-
         base_class = ''
         if issubclass(type(task), IntegrationTask):
             base_class = 'IntegrationTask'
@@ -537,7 +536,6 @@ class Automation:
 
         return df
 
-
     @staticmethod
     def deploy_as_email_data_feed(task, api_inputs: ApiInputs, expected_delivery: EXPECTED_DELIVERY,
                                   email_subject_regex: str, email_address_domain='switchautomation.com',
@@ -718,7 +716,8 @@ class Automation:
             logger.error('No data returned for this API call. %s', response.request.__dict__)
             return response_status, pandas.DataFrame()
 
-        df = pandas.read_json(response.text, typ='Series')
+        df = pandas.read_json(response.text, typ='Series').to_frame().T
+        df.columns = _column_name_cap(df.columns)
 
         return df
 
@@ -845,21 +844,21 @@ class Automation:
             logger.error("cron_schedule parameter must be in the format * * * * * *")
             return pandas.DataFrame()
 
-        # TODO - discuss whether this is required since we added the Literal EXPECTED_DELIVERY
-        expected_deliveries = re.findall(r'[A-Za-z]+|\d+', expected_delivery)
-        if len(expected_deliveries) != 2 or expected_deliveries[0].isnumeric() is not True:
-            logger.error("Run At parameter must take the form of a number followed by a time type. ")
-            return pandas.DataFrame()
-
-        time_type = expected_deliveries[1].lower()[:3]
-        if time_type != 'min' and time_type != 'hour' and time_type != 'day':
-            logger.error("The expected_delivery time type must start with one of: min, hour, day. ")
-            return pandas.DataFrame()
+        # # TODO - discuss whether this is required since we added the Literal EXPECTED_DELIVERY
+        # expected_deliveries = re.findall(r'[A-Za-z]+|\d+', expected_delivery)
+        # if len(expected_deliveries) != 2 or expected_deliveries[0].isnumeric() is not True:
+        #     logger.error("Run At parameter must take the form of a number followed by a time type. ")
+        #     return pandas.DataFrame()
+        #
+        # time_type = expected_deliveries[1].lower()[:3]
+        # if time_type != 'min' and time_type != 'hour' and time_type != 'day':
+        #     logger.error("The expected_delivery time type must start with one of: min, hour, day. ")
+        #     return pandas.DataFrame()
 
         logger.info('Deploy %s (%s) on timer for ApiProjectID: %s and schedule: %s.', type(task).__name__,
                     str(task.id), api_inputs.api_project_id, cron_schedule)
         logger.info('Feed Type is %s', str(task.mapping_entities))
-        logger.info('Settings to be passed tothe driver on start are: %s', str(settings))
+        logger.info('Settings to be passed to the driver on start are: %s', str(settings))
 
         headers = {
             'x-functions-key': api_inputs.api_key,
@@ -944,7 +943,7 @@ class Automation:
         # payload = {}
 
         url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Automation/CancelTask/" + \
-              deploy_type + "/" + str(task.id)
+            deploy_type + "/" + str(task.id)
 
         response = requests.get(url, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
@@ -991,7 +990,7 @@ class Automation:
         }
 
         url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Automation/ListDeployments/" + \
-              search_name_pattern
+            search_name_pattern
 
         response = requests.request("GET", url, timeout=20, headers=headers)
         response_status = '{} {}'.format(response.status_code, response.reason)
@@ -1040,7 +1039,7 @@ class Automation:
         }
 
         url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-              "/Automation/ListDataFeedsHistory/" + str(data_feed_id) + "/" + str(top_count)
+            "/Automation/ListDataFeedsHistory/" + str(data_feed_id) + "/" + str(top_count)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
 
@@ -1118,8 +1117,8 @@ class Automation:
         }
 
         url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-              "/Automation/DataFeedsProcessOutput/" + str(data_feed_id) + "/" + str(data_feed_file_status_id) + "/" + \
-              str(row_number)
+            "/Automation/DataFeedsProcessOutput/" + str(data_feed_id) + "/" + str(data_feed_file_status_id) + "/" + \
+            str(row_number)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
 
@@ -1177,7 +1176,7 @@ class Automation:
         }
 
         url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-              "/Automation/DataFeedsProcessErrors/" + str(data_feed_id) + "/" + str(data_feed_file_status_id)
+            "/Automation/DataFeedsProcessErrors/" + str(data_feed_id) + "/" + str(data_feed_file_status_id)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
 
@@ -1220,7 +1219,8 @@ class Automation:
 
         """
 
-        if data_feed_id == '' or data_feed_file_status_id == '' or data_feed_id is None or data_feed_file_status_id is None:
+        if (data_feed_id == '' or data_feed_file_status_id == '' or data_feed_id is None or
+                data_feed_file_status_id is None):
             logger.error('The data_feed_id and data_feed_file_status_id parameters must be provided. ')
             return
 
@@ -1236,8 +1236,8 @@ class Automation:
         }
 
         url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-              "/Automation/DataFeedsProcessGetErrorsByType/" + str(data_feed_id) + "/" + str(data_feed_file_status_id) \
-              + "/" + str(error_type)
+            "/Automation/DataFeedsProcessGetErrorsByType/" + str(data_feed_id) + "/" + str(data_feed_file_status_id) \
+            + "/" + str(error_type)
 
         response = requests.request("GET", url, timeout=20, headers=headers)
 
